@@ -311,6 +311,13 @@ SRXAFSCB_Probe(struct rx_call *callp)
 	return 0;
 }
 
+/* debug interface: not implemented */
+SRXAFSCB_GetCE64(struct rx_call *callp, long index, AFSDBCacheEntry *cep)
+{
+    /* XXXX */
+    return RXGEN_OPCODE;
+}
+
 /* debug interface: not implemented */
 SRXAFSCB_GetLock(struct rx_call *callp, long index, AFSDBLock *lockp)
 {
