@@ -10,7 +10,11 @@
 #ifndef	__CM_RPC_H__
 #define __CM_RPC_H__
 
+#ifndef DJGPP
 #include "afsrpc.h"
+#else
+#include "afsrpc95.h"
+#endif
 
 void cm_RegisterNewTokenEvent(afs_uuid_t uuid, char sessionKey[8]);
 BOOL cm_FindTokenEvent(afs_uuid_t uuid, char sessionKey[8]);
