@@ -11,10 +11,17 @@
  * Linux support routines.
  *
  */
+#include <afsconfig.h>
 #include "../afs/param.h"
+
+RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_misc.c,v 1.12.2.1 2002/01/24 10:43:17 shadow Exp $");
+
 #include "../afs/sysincludes.h"
 #include "../afs/afsincludes.h"
 #include "../afs/afs_stats.h"
+#if defined(AFS_LINUX24_ENV)
+#include "../h/smp_lock.h"
+#endif
 
 char *crash_addr = 0; /* Induce an oops by writing here. */
 
@@ -42,11 +49,10 @@ int osi_lookupname(char *aname, uio_seg_t seg, int followlink,
 
     if (!code) {
 	if (nd.dentry->d_inode) {
-	    *dpp = nd.dentry;
+	    *dpp = dget(nd.dentry);
 	    code = 0;
 	}
-	else
-	    path_release(&nd);
+	path_release(&nd);
     }
 #else
     if (seg == AFS_UIOUSER) {
@@ -299,7 +305,13 @@ void osi_linux_free_inode_pages(void)
 #else
 	    if (ip->i_nrpages) {
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
+	        truncate_inode_pages(&ip->i_data, 0);
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2,2,15)
+	        truncate_inode_pages(ip, 0);
+#else
 		invalidate_inode_pages(ip);
+#endif
 #if defined(AFS_LINUX24_ENV)
 		if (ip->i_data.nrpages) {
 #else
@@ -313,16 +325,39 @@ void osi_linux_free_inode_pages(void)
     }
 }
 
+void osi_clear_inode(struct inode *ip)
+{
+    cred_t *credp = crref();
+    struct vcache *vc = (struct vcache*)ip;
+
+#if defined(AFS_LINUX24_ENV)
+    if (atomic_read(&ip->i_count) > 1)
+#else
+    if (ip->i_count > 1)
+#endif
+        printf("afs_put_inode: ino %d (0x%x) has count %d\n", ip->i_ino, ip);
+
+    ObtainWriteLock(&vc->lock, 504);
+    afs_InactiveVCache(vc, credp);
+    ReleaseWriteLock(&vc->lock);
+#if defined(AFS_LINUX24_ENV)
+    atomic_set(&ip->i_count, 0);
+#else
+    ip->i_count = 0;
+#endif
+    ip->i_nlink = 0; /* iput checks this after calling this routine. */
+    crfree(credp);
+}
+
 /* iput an inode. Since we still have a separate inode pool, we don't want
  * to call iput on AFS inodes, since they would then end up on Linux's
  * inode_unsed list.
  */
 void osi_iput(struct inode *ip)
 {
-    extern void afs_delete_inode(struct inode *ip);
     extern struct vfs *afs_globalVFS;
 
-    
+    AFS_GLOCK();
 #if defined(AFS_LINUX24_ENV)
     if (atomic_read(&ip->i_count) == 0 || atomic_read(&ip->i_count) & 0xffff0000) {
 #else
@@ -343,11 +378,11 @@ void osi_iput(struct inode *ip)
 	ip->i_count --;
 	if (!ip->i_count)
 #endif
-	    afs_delete_inode(ip);
+	    osi_clear_inode(ip);
     }
-    else { 
+    else
 	iput(ip);
-    }
+    AFS_GUNLOCK();
 }
 
 /* check_bad_parent() : Checks if this dentry's vcache is a root vcache
@@ -385,8 +420,30 @@ void check_bad_parent(struct dentry *dp)
 		 ICL_TYPE_POINTER, avc,
 		 ICL_TYPE_POINTER, dp);
     }
-    
+    if (avc)
+	AFS_RELE(avc);
+    crfree(credp);
   } /* if bad parent */
  
   return;
 }
+
+struct task_struct *rxk_ListenerTask;
+
+void osi_linux_mask() {
+    spin_lock_irq(&current->sigmask_lock);
+    sigfillset(&current->blocked);
+    recalc_sigpending(current);
+    spin_unlock_irq(&current->sigmask_lock);
+}
+
+void osi_linux_unmask() {
+    spin_lock_irq(&rxk_ListenerTask->sigmask_lock);
+    sigemptyset(&rxk_ListenerTask->blocked);
+    recalc_sigpending(rxk_ListenerTask);
+    spin_unlock_irq(&rxk_ListenerTask->sigmask_lock);
+}
+
+void osi_linux_rxkreg() {
+    rxk_ListenerTask = current;
+}
