@@ -15,7 +15,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_vfsops.c,v 1.11 2001/08/28 18:03:49 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/LINUX/osi_vfsops.c,v 1.11.2.2 2002/01/29 19:45:07 shadow Exp $");
 
 #include "../afs/sysincludes.h"
 #include "../afs/afsincludes.h"
@@ -78,6 +78,7 @@ struct super_block *afs_read_super(struct super_block *sb, void *data,
     AFS_GLOCK();
     if (afs_was_mounted) {
 	printf("You must reload the AFS kernel extensions before remounting AFS.\n");
+	AFS_GUNLOCK();
 	return NULL;
     }
     afs_was_mounted = 1;
@@ -335,8 +336,8 @@ int afs_statfs(struct super_block *sbp, struct statfs *statp, int size)
 void 
 afs_umount_begin(struct super_block *sbp)
 {
-    afs_shuttingdown=1;
     afs_put_super(sbp);      
+    afs_shuttingdown=1;
     afs_was_mounted=0;
 }
 
@@ -347,7 +348,7 @@ struct super_operations afs_sops = {
     delete_inode:      afs_delete_inode,
     put_super:         afs_put_super,
     statfs:            afs_statfs,
-    umount_begin:      afs_umount_begin,
+    umount_begin:      NULL /* afs_umount_begin */
 };
 #else
 struct super_operations afs_sops = {
@@ -361,7 +362,7 @@ struct super_operations afs_sops = {
     afs_statfs,
     NULL,		/* afs_remount_fs - see doc above */
     NULL,		/* afs_clear_inode */
-    afs_umount_begin,
+    NULL                /* afs_umount_begin */
 };
 #endif
 
