@@ -189,6 +189,7 @@ struct afs_cbr {
 #define	CNoSUID		    2	    /* 1 if no suid progs can run from this cell */
 #define CHasVolRef	   16	    /* Volumes were referenced in this cell*/
 #define CLinkedCell	   32
+#define CAlias		   64	    /* This cell entry is an alias */
 
 struct cell {
     struct afs_q lruq;			     /* lru q next and prev */
@@ -201,6 +202,7 @@ struct cell {
     short states;			    /* state flags */
     short cellIndex;			    /* relative index number per cell */
     time_t timeout;			    /* data expire time, if non-zero */
+    char *realName;			    /* who this cell is an alias for */
 };
 
 #define	afs_PutCell(cellp, locktype)
@@ -522,6 +524,26 @@ struct SimpleLocks {
 #define vrefCount   v.v_usecount
 #endif /* AFS_FBSD_ENV */
 
+#ifdef AFS_LINUX24_ENV
+#define VREFCOUNT(v)		atomic_read(&((vnode_t *) v)->v_count)
+#define VREFCOUNT_SET(v, c)	atomic_set(&((vnode_t *) v)->v_count, c)
+#define VREFCOUNT_DEC(v)	atomic_dec(&((vnode_t *) v)->v_count)
+#define VREFCOUNT_INC(v)	atomic_inc(&((vnode_t *) v)->v_count)
+#define DLOCK()      spin_lock(&dcache_lock)
+#define DUNLOCK()    spin_unlock(&dcache_lock)
+#define DGET(d)      dget_locked(d)
+#define DCOUNT(d)    atomic_read(&(d)->d_count)
+#else
+#define VREFCOUNT(v)		((v)->vrefCount)
+#define VREFCOUNT_SET(v, c)	(v)->vrefCount = c;
+#define VREFCOUNT_DEC(v)	(v)->vrefCount--;
+#define VREFCOUNT_INC(v)	(v)->vrefCount++;
+#define DLOCK()
+#define DUNLOCK()
+#define DGET(d)      dget(d)
+#define DCOUNT(d)    ((d)->d_count)
+#endif
+
 #define	AFS_MAXDV   0x7fffffff	    /* largest dataversion number */
 #define	AFS_NOTRUNC 0x7fffffff	    /* largest dataversion number */
 
@@ -945,7 +967,10 @@ extern struct brequest afs_brs[NBRS];		/* request structures */
 #define	FVHash(acell,avol)  (((avol)+(acell)) & (NFENTRIES-1))
 
 extern struct cell	    *afs_GetCell();
+extern struct cell	    *afs_GetCellNoLock();
 extern struct cell	    *afs_GetCellByName();
+extern struct cell	    *afs_GetCellByName2();
+extern struct cell	    *afs_GetCellByIndex();
 extern struct unixuser	    *afs_GetUser();
 extern struct volume	    *afs_GetVolume();
 extern struct volume	    *afs_GetVolumeByName();
@@ -978,6 +1003,19 @@ extern void afs_shutdown();
 /* afs_osifile.c */
 extern void shutdown_osifile();
 
+/* afs_dynroot.c */
+extern int afs_IsDynrootFid();
+extern void afs_GetDynrootFid();
+extern int afs_IsDynroot();
+extern void afs_RefreshDynroot();
+extern void afs_GetDynroot();
+extern void afs_PutDynroot();
+extern int afs_DynrootNewVnode();
+extern int afs_SetDynrootEnable();
+extern int afs_GetDynrootEnable();
+extern int afs_DynrootVOPSymlink();
+extern int afs_DynrootVOPRemove();
+
 
 /* Performance hack - we could replace VerifyVCache2 with the appropriate
  * GetVCache incantation, and could eliminate even this code from afs_UFSRead 
@@ -1036,6 +1074,7 @@ extern int afs_CacheTooFull;
  * afs_GetDownD wakes those processes once the cache is 95% full
  * (CM_CACHESIZEDRAINEDPCT).
  */
+extern void afs_MaybeWakeupTruncateDaemon();
 extern void afs_CacheTruncateDaemon();
 extern int afs_WaitForCacheDrain;
 #define CM_MAXDISCARDEDCHUNKS	16      /* # of chunks */
@@ -1051,19 +1090,6 @@ extern int afs_WaitForCacheDrain;
      afs_freeDCCount - afs_discardDCCount < \
 	((100-CM_DCACHECOUNTFREEPCT)*afs_cacheFiles)/100)
 
-#define	afs_MaybeWakeupTruncateDaemon()	\
-    do { \
-	if (!afs_CacheTooFull && afs_CacheIsTooFull()) { \
-	    afs_CacheTooFull = 1; \
-            if (!afs_TruncateDaemonRunning) { \
-		afs_osi_Wakeup((char *)afs_CacheTruncateDaemon); \
-	    } \
-	} else if (!afs_TruncateDaemonRunning && \
-		   afs_blocksDiscarded > CM_MAXDISCARDEDCHUNKS) { \
-	    afs_osi_Wakeup((char *)afs_CacheTruncateDaemon); \
-	} \
-    } while (0)
-
 /* Handy max length of a numeric string. */
 #define	CVBS	12  /* max afs_int32 is 2^32 ~ 4*10^9, +1 for NULL, +luck */
 
