@@ -38,7 +38,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/afs_vcache.c,v 1.9.2.1 2001/10/13 04:20:24 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/afs_vcache.c,v 1.9.2.6 2002/01/23 09:30:36 shadow Exp $");
 
 #include "../afs/sysincludes.h" /*Standard vendor system headers*/
 #include "../afs/afsincludes.h" /*AFS-based standard headers*/
@@ -525,7 +525,6 @@ afs_RemoveVCB(afid)
 } /*afs_RemoveVCB*/
 
 
-
 /*
  * afs_NewVCache
  *
@@ -563,29 +562,25 @@ struct vcache *afs_NewVCache(struct VenusFid *afid, struct server *serverp,
 #ifdef AFS_LINUX22_ENV
     if (!freeVCList) {
 	/* Free some if possible. */
-	 struct afs_q *tq, *uq;
-	 int i; char *panicstr;
-	 int vmax = 2 * afs_cacheStats;
-	 int vn = VCACHE_FREE;
-
-         AFS_GUNLOCK();
-	 shrink_dcache_sb(afs_globalVFS);
-	 AFS_GLOCK();
-
-	 i = 0;
-	 for(tq = VLRU.prev; tq != &VLRU && vn > 0; tq = uq) {
+        struct afs_q *tq, *uq;
+        int i; char *panicstr;
+        int vmax = 2 * afs_cacheStats;
+        int vn = VCACHE_FREE;
+	
+        i = 0;
+        for(tq = VLRU.prev; tq != &VLRU && vn > 0; tq = uq) {
 	    tvc = QTOV(tq);
 	    uq = QPrev(tq);
 	    if (tvc->states & CVFlushed) 
-		 refpanic ("CVFlushed on VLRU");
+                refpanic ("CVFlushed on VLRU");
 	    else if (i++ > vmax)
-		 refpanic ("Exceeded pool of AFS vnodes(VLRU cycle?)");
+                refpanic ("Exceeded pool of AFS vnodes(VLRU cycle?)");
 	    else if (QNext(uq) != tq)
-		 refpanic ("VLRU inconsistent");
-
+                refpanic ("VLRU inconsistent");
+	    
 	    if (tvc == afs_globalVp)
 		continue;
-
+	    
 	    if ( VREFCOUNT(tvc) && tvc->opens == 0 ) {
 		struct inode *ip = (struct inode*)tvc;
 		if (list_empty(&ip->i_dentry)) {
@@ -596,24 +591,14 @@ struct vcache *afs_NewVCache(struct VenusFid *afid, struct server *serverp,
 		    struct list_head *head = &ip->i_dentry;
 		    int all = 1;
 		restart:
-#if defined(AFS_LINUX24_ENV)
-		    spin_lock(&dcache_lock);
-#endif
+		    DLOCK();
 		    cur = head;
 		    while ((cur = cur->next) != head) {
 			struct dentry *dentry = list_entry(cur, struct dentry, d_alias);
-#if defined(AFS_LINUX24_ENV)
-			if (!atomic_read(&dentry->d_count)) {
-#else
-			if (!dentry->d_count) {
-#endif
+			if (!DCOUNT(dentry)) {
 			    AFS_GUNLOCK();
-#if defined(AFS_LINUX24_ENV)
-			    dget_locked(dentry);
-			    spin_unlock(&dcache_lock);
-#else
-			    dget(dentry);
-#endif
+			    DGET(dentry);
+			    DUNLOCK();
 			    d_drop(dentry);
 			    dput(dentry);
 			    AFS_GLOCK();
@@ -623,14 +608,12 @@ struct vcache *afs_NewVCache(struct VenusFid *afid, struct server *serverp,
 			    all = 0;
 			}
 		    }
-#if defined(AFS_LINUX24_ENV)
-		    spin_unlock(&dcache_lock);
-#endif
+		    DUNLOCK();
 		    if (all) vn --;
 		}
 	    }
 	    if (tq == uq) break;
-	 }
+        }
     }
 #endif /* AFS_LINUX22_ENV */
 #ifdef	AFS_OSF_ENV
@@ -962,8 +945,17 @@ struct vcache *afs_NewVCache(struct VenusFid *afid, struct server *serverp,
 	INIT_LIST_HEAD(&ip->i_data.dirty_pages);
 	INIT_LIST_HEAD(&ip->i_data.locked_pages);
 	INIT_LIST_HEAD(&ip->i_dirty_buffers);
+#ifdef STRUCT_INODE_HAS_I_DIRTY_DATA_BUFFERS
+	INIT_LIST_HEAD(&ip->i_dirty_data_buffers);
+#endif
+#ifdef STRUCT_INODE_HAS_I_DEVICES
+	INIT_LIST_HEAD(&ip->i_devices);
+#endif
 	ip->i_data.host = (void*) ip;
 	ip->i_mapping = &ip->i_data;
+#ifdef STRUCT_INODE_HAS_I_TRUNCATE_SEM
+	init_rwsem(&ip->i_truncate_sem);
+#endif
 #else
 	sema_init(&ip->i_atomic_write, 1);
 	init_waitqueue(&ip->i_wait);
