@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include "../afs/param.h"
 
-RCSID("$Header: /cvs/openafs/src/afs/afs_volume.c,v 1.5 2001/07/12 19:58:15 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afs/afs_volume.c,v 1.6.2.3 2001/12/26 20:44:31 shadow Exp $");
 
 #include "../afs/stds.h"
 #include "../afs/sysincludes.h"	/* Standard vendor system headers */
@@ -56,12 +56,11 @@ extern struct srvAddr *afs_srvAddrs[NSERVERS];  /* Hashed by server's ip */
 extern int afs_totalSrvAddrs;
 
 /* In case we don't have the vl error table yet. */
-#ifndef ERROR_TABLE_BASE_vl
-#define ERROR_TABLE_BASE_vl	(363520L)
-#define VL_NOENT		(363524L)
+#ifndef ERROR_TABLE_BASE_VL
+#define ERROR_TABLE_BASE_VL     (363520L)
+#define VL_NOENT                (363524L)
 #endif /* vlserver error base define */
 
-
 /* Exported variables */
 ino_t volumeInode;			/*Inode for VolumeItems file*/
 afs_rwlock_t afs_xvolume;               /* allocation lock for volumes */
@@ -73,6 +72,7 @@ afs_int32 fvTable[NFENTRIES];
 /* Forward declarations */
 static struct volume *afs_NewVolumeByName(char *aname, afs_int32 acell, int agood,
 				   struct vrequest *areq, afs_int32 locktype);
+static struct volume *afs_NewDynrootVolume(struct VenusFid *fid);
 static inVolList();
 
 
@@ -225,6 +225,7 @@ void afs_ResetVolumes(struct server *srvp)
      for (vp=afs_volumes[j]; vp; vp=vp->next) {
 	for (k=0; k<MAXHOSTS; k++) {
 	   if (!srvp || (vp->serverHost[k] == srvp)) {
+	      vp->serverHost[k] = 0;
 	      afs_ResetVolumeInfo(vp);
 	      break;
 	   }
@@ -403,8 +404,12 @@ struct volume *afs_GetVolume(afid, areq, locktype)
 
     tv = afs_FindVolume(afid, locktype);
     if (!tv) {
-       bp = afs_cv2string(&tbuf[CVBS], afid->Fid.Volume);
-       tv = afs_NewVolumeByName(bp, afid->Cell, 0, areq, locktype);
+       if (afs_IsDynrootFid(afid)) {
+          tv = afs_NewDynrootVolume(afid);
+       } else {
+          bp = afs_cv2string(&tbuf[CVBS], afid->Fid.Volume);
+          tv = afs_NewVolumeByName(bp, afid->Cell, 0, areq, locktype);
+       }
     }
     return tv;
 } /*afs_GetVolume*/
@@ -464,7 +469,7 @@ static struct volume *afs_SetupVolume(volid, aname, ve, tcell, agood, type, areq
 	struct fvolume *tf=0;
 
 	tv = afs_GetVolSlot();
-	bzero((char *)tv, sizeof(struct volume));
+	memset((char *)tv, 0, sizeof(struct volume));
 	tv->cell = tcell->cell;
 	RWLOCK_INIT(&tv->lock, "volume lock");
 	tv->next = afs_volumes[i];	/* thread into list */
@@ -550,6 +555,29 @@ struct volume *afs_GetVolumeByName(aname, acell, agood, areq, locktype)
   return(tv);
 }
 
+static struct volume *afs_NewDynrootVolume(struct VenusFid *fid) {
+    struct cell *tcell;
+    struct volume *tv;
+    struct vldbentry tve;
+    char *bp, tbuf[CVBS];
+
+    tcell = afs_GetCell(fid->Cell, READ_LOCK);
+    if (!tcell)
+	return (struct volume *) 0;
+    if (!(tcell->states & CHasVolRef))
+	tcell->states |= CHasVolRef;
+
+    bp = afs_cv2string(&tbuf[CVBS], fid->Fid.Volume);
+    memset(&tve, 0, sizeof(tve));
+    strcpy(tve.name, "local-dynroot");
+    tve.volumeId[ROVOL] = fid->Fid.Volume;
+    tve.flags = VLF_ROEXISTS;
+
+    tv = afs_SetupVolume(0, bp, &tve, tcell, 0, 0, 0);
+    afs_PutCell(tcell, READ_LOCK);
+    return tv;
+}
+
 int lastnvcode;
 static struct volume *afs_NewVolumeByName(char *aname, afs_int32 acell, int agood,
 				   struct vrequest *areq, afs_int32 locktype)
@@ -912,11 +940,11 @@ void InstallUVolumeEntry(struct volume *av, struct uvldbentry *ve,
 		ListAddrByAttributes attrs;
 		afsUUID uuid;
 
-		bzero((char *)&attrs, sizeof(attrs));
+		memset((char *)&attrs, 0, sizeof(attrs));
 		attrs.Mask = VLADDR_UUID;
 		attrs.uuid = ve->serverNumber[i];
-		bzero((char *)&uuid, sizeof(uuid));
-		bzero((char *)&addrs, sizeof(addrs));
+		memset((char *)&uuid, 0, sizeof(uuid));
+		memset((char *)&addrs, 0, sizeof(addrs));
 		do {
 		    tconn = afs_ConnByMHosts(tcell->cellHosts, tcell->vlport,
 					     tcell->cell, areq, SHARED_LOCK);
