@@ -55,7 +55,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/afsd/afsd.c,v 1.13 2001/08/02 16:16:34 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/afsd/afsd.c,v 1.13.2.5 2002/01/20 08:20:58 shadow Exp $");
 
 #define VFS 1
 
@@ -113,6 +113,14 @@ RCSID("$Header: /cvs/openafs/src/afsd/afsd.c,v 1.13 2001/08/02 16:16:34 shadow E
 #include <sys/vfs.h>
 #endif
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #include <netinet/in.h>
 #include <afs/afs_args.h>
 #include <afs/cellconfig.h>
@@ -146,7 +154,7 @@ void set_staticaddrs(void);
 #if AFS_HAVE_STATVFS
 #include <sys/statvfs.h>
 #else
-#if !defined(AFS_OSF_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
+#if !defined(AFS_OSF_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_XBSD_ENV)
 #include <sys/statfs.h>
 #endif
 #endif
@@ -231,6 +239,7 @@ static int enable_process_stats = 0;	/* enable rx stats */
 #ifdef AFS_AFSDB_ENV
 static int enable_afsdb = 0;		/* enable AFSDB support */
 #endif
+static int enable_dynroot = 0;		/* enable dynroot support */
 #ifdef notdef
 static int inodes = 60;		        /* VERY conservative, but has to be */
 #endif
@@ -797,6 +806,10 @@ static int doSweepAFSCache(vFilesFound,directory,dirNum,maxDir)
 		  (strcmp(currp->d_name,         ".tags") == 0) ||
 		  (strcmp(currp->d_name,         "quota.user") == 0) ||
 		  (strcmp(currp->d_name,         "quota.group") == 0) ||
+#endif
+#ifdef AFS_LINUX22_ENV
+		  /* this is the ext3 journal file */
+		  (strcmp(currp->d_name,         ".journal") == 0) ||
 #endif
 		  (strcmp(currp->d_name, "lost+found") == 0)) {
 	    /*
@@ -1049,6 +1062,16 @@ struct afsconf_dir *adir; {
     return 0;
 }
 
+static ConfigCellAlias(aca, arock, adir)
+    register struct afsconf_cellalias *aca;
+    char *arock;
+    struct afsconf_dir *adir;
+{
+    /* push the alias into the kernel */
+    call_syscall(AFSOP_ADDCELLALIAS, aca->aliasName, aca->realName);
+    return 0;
+}
+
 #ifdef AFS_AFSDB_ENV
 static AfsdbLookupHandler()
 {
@@ -1058,6 +1081,10 @@ static AfsdbLookupHandler()
     struct afsconf_cell acellInfo;
     int i;
 
+    kernelMsg[0] = 0;
+    kernelMsg[1] = 0;
+    acellName[0] = '\0';
+
     while (1) {
 	/* On some platforms you only get 4 args to an AFS call */
 	int sizeArg = ((sizeof acellName) << 16) | (sizeof kernelMsg);
@@ -1067,6 +1094,9 @@ static AfsdbLookupHandler()
 	    continue;
 	}
 
+	if (*acellName == 1)	/* Shutting down */
+	    break;
+
 	code = afsconf_GetAfsdbInfo(acellName, 0, &acellInfo);
 	if (code) {
 	    kernelMsg[0] = 0;
@@ -1079,8 +1109,12 @@ static AfsdbLookupHandler()
 		kernelMsg[1] = 0;
 	    for (i=0; i<acellInfo.numServers; i++)
 		kernelMsg[i+2] = acellInfo.hostAddr[i].sin_addr.s_addr;
+	    strncpy(acellName, acellInfo.name, sizeof(acellName));
+	    acellName[sizeof(acellName) - 1] = '\0';
 	}    
     }
+
+    exit(1);
 }
 #endif
 
@@ -1288,6 +1322,10 @@ mainproc(as, arock)
 	    nFilesPerDir = res;
 	}
     }
+    if (as->parms[26].items) {
+	/* -dynroot */
+	enable_dynroot = 1;
+    }
 
     /*
      * Pull out all the configuration info for the workstation's AFS cache and
@@ -1519,6 +1557,14 @@ mainproc(as, arock)
     }
 #endif
 
+    if (enable_dynroot) {
+	if (afsd_verbose)
+	    printf("%s: Enabling dynroot support in kernel.\n", rn);
+	code = call_syscall(AFSOP_SET_DYNROOT, 1);
+	if (code)
+	    printf("%s: Error enabling dynroot support.\n", rn);
+    }
+
     /* Initialize AFS daemon threads. */
     if (afsd_verbose)
 	printf("%s: Forking AFS daemon.\n", rn);
@@ -1580,6 +1626,7 @@ mainproc(as, arock)
     lookingForHomeCell = 1;
 
     afsconf_CellApply(cdir, ConfigCell, (char *) 0);
+    afsconf_CellAliasApply(cdir, ConfigCellAlias, (char *) 0);
 
     /*
      * If we're still looking for the home cell after the whole cell configuration database
@@ -1870,6 +1917,7 @@ char **argv; {
 #endif
 		), "Enable AFSDB support");
     cmd_AddParm(ts, "-files_per_subdir", CMD_SINGLE, CMD_OPTIONAL, "log(2) of the number of cache files per cache subdirectory");
+    cmd_AddParm(ts, "-dynroot", CMD_FLAG, CMD_OPTIONAL, "Enable dynroot support");
     return (cmd_Dispatch(argc, argv));
 }
 
@@ -1951,9 +1999,19 @@ call_syscall(param1, param2, param3, param4, param5, param6, param7)
 long param1, param2, param3, param4, param5, param6, param7;
 {
     int error;
+#ifdef AFS_LINUX20_ENV
+    long eparm[4];
+
+    eparm[0] = param4;
+    eparm[1] = param5;
+    eparm[2] = param6;
+    eparm[3] = param7;
+
+    param4 = eparm;
+#endif
 
     error = syscall(AFS_SYSCALL, AFSCALL_CALL, param1, param2, param3, param4, param5, param6, param7);
-    if (afsd_verbose) printf("SScall(%d, %d)=%d ", AFS_SYSCALL, AFSCALL_CALL, error);
+    if (afsd_verbose) printf("SScall(%d, %d, %d)=%d ", AFS_SYSCALL, AFSCALL_CALL, param1, error);
     return (error);
 }
 #else	/* AFS_AIX32_ENV */
