@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/bozo/bosserver.c,v 1.12.2.2 2001/10/13 04:21:04 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/bozo/bosserver.c,v 1.12.2.3 2002/01/20 09:06:15 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -670,7 +670,9 @@ char **envp;
     struct ktc_encryptionKey tkey;
     int i;
     char namebuf[AFSDIR_PATH_MAX];
-
+#ifndef AFS_NT40_ENV
+    int nofork = 0;
+#endif
 #ifdef	AFS_AIX32_ENV
     struct sigaction nsa;
 
@@ -748,6 +750,9 @@ char **envp;
 	    DoSyslog = 1;
 	    DoSyslogFacility = atoi(argv[code]+8);
 	}
+	else if (strcmp(argv[code], "-nofork")==0) {
+	    nofork = 1;
+	}
 #endif
 	else if (strcmp(argv[code], "-enable_peer_stats")==0) {
 	    rx_enablePeerRPCStats();
@@ -768,6 +773,7 @@ char **envp;
 	    printf("Usage: bosserver [-noauth] [-log] "
 		   "[-syslog[=FACILITY]] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
+		   "[-nofork] "
 		   "[-help]\n");
 #else
 	    printf("Usage: bosserver [-noauth] [-log] "
@@ -811,6 +817,7 @@ char **envp;
     /* go into the background and remove our controlling tty */
 
 #ifndef AFS_NT40_ENV
+    if (!nofork)
     background();
 #endif /* ! AFS_NT40_ENV */
 
