@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/butc/tcmain.c,v 1.5 2001/08/08 00:03:40 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/butc/tcmain.c,v 1.5.2.3 2001/12/26 20:26:09 shadow Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -355,7 +355,7 @@ static afs_int32 GetDeviceConfig(filename, config, portOffset)
         count = sscanf(line, "%s %s %s %u%s\n",
 		      tcapacity, tfmsize, devName, &aport, trest);
 
-	if (count == 4) {
+	if (count == 4 || count == 5) {
 	    if ( atocl(tcapacity, 'K', &capacity) ) {
 	       fprintf(stderr, "tapeconfig: Tape capacity parse error in: %s\n", line);
 	       ERROR_EXIT(-1);
@@ -366,7 +366,7 @@ static afs_int32 GetDeviceConfig(filename, config, portOffset)
 	    }
 	} else {
 	    count = sscanf(line, "%s %u%s\n", devName, &aport, trest);
-	    if (count == 2) {
+	    if (count == 2 || count == 3) {
 	        capacity = 0x7fffffff;
 		fmSize = 0;
 	    } else {
@@ -838,20 +838,20 @@ char *arock; {
     debugLevel = 0;
 
     /*initialize the error tables */
-    initialize_ka_error_table();
-    initialize_rxk_error_table();
-    initialize_ktc_error_table();
-    initialize_acfg_error_table();
-    initialize_cmd_error_table();
-    initialize_vl_error_table();
-    initialize_butm_error_table();
-    initialize_butc_error_table();
+    initialize_KA_error_table();
+    initialize_RXK_error_table();
+    initialize_KTC_error_table();
+    initialize_ACFG_error_table();
+    initialize_CMD_error_table();
+    initialize_VL_error_table();
+    initialize_BUTM_error_table();
+    initialize_BUTC_error_table();
 #ifdef xbsa
-    initialize_butx_error_table();
+    initialize_BUTX_error_table();
 #endif /*xbs*/
-    initialize_vols_error_table();
-    initialize_budb_error_table();
-    initialize_bucd_error_table();
+    initialize_VOLS_error_table();
+    initialize_BUDB_error_table();
+    initialize_BUCD_error_table();
 
     if (as->parms[0].items)
     {
