@@ -37,17 +37,18 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/des/crypt.c,v 1.5 2001/07/12 19:58:34 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/des/crypt.c,v 1.7 2001/08/07 00:05:00 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <windows.h>
 #endif
 #include <stdlib.h>
-#if defined(HAVE_STRINGS_H)
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
-#if defined(HAVE_STRING_H)
-#include <string.h>
 #endif
 
 /*
@@ -248,8 +249,13 @@ typedef union {
 	struct {
 #if defined(LONG_IS_32_BITS)
 		/* long is often faster than a 32-bit bit field */
+#if defined(AFS_IA64_LINUX20_ENV)
+		int	i0;
+		int	i1;
+#else
 		long	i0;
 		long	i1;
+#endif
 #else
 		long	i0: 32;
 		long	i1: 32;
@@ -500,6 +506,7 @@ crypt(key, setting)
 	int num_iter, salt_size;
 	C_block keyblock, rsltblock;
 
+
 	for (i = 0; i < 8; i++) {
 		if ((t = 2*(unsigned char)(*key)) != 0)
 			key++;
