@@ -13,9 +13,8 @@
 
 /* Unsafe: conflicts with _KERNEL inclusion of headers below */
 /* #include <afs/param.h> */
-#include <afsconfig.h>
-
-RCSID("$Header: /cvs/openafs/src/export/export.c,v 1.4 2001/07/06 04:19:54 shadow Exp $");
+/* #include <afsconfig.h> */
+/* RCSID("$Header: /cvs/openafs/src/export/export.c,v 1.4.4.1 2001/12/26 20:17:52 shadow Exp $"); */
 
 #define _KERNEL
 #include "sys/types.h"
