@@ -12,7 +12,11 @@
    make small changes as well as subroutines to permit specialized programs to
    update the database, change the server passwords, etc. */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/kauth/admin_tools.c,v 1.8.2.2 2001/10/13 04:21:33 shadow Exp $");
+
 #include <afs/stds.h>
 #include <afs/debug.h>
 #include <ctype.h>
@@ -633,7 +637,7 @@ int SetFields (
 
       hrs = 0;
       s = as->parms[7].items->data;
-      if (index(s, ':'))
+      if (strchr(s, ':'))
 	sscanf(s, "%d:%d", &hrs, &mins);
       else
 	sscanf(s, "%d", &mins);
@@ -707,6 +711,13 @@ int StringToKey (
     ka_PrintBytes ((char *)&key, sizeof(key));
     printf ("'.\n");
 
+    des_string_to_key (as->parms[0].items->data, &key);
+      
+    printf ("Converting %s with the DES string to key yields key='",
+	    as->parms[0].items->data);
+    ka_PrintBytes ((char *)&key, sizeof(key));
+    printf ("'.\n");
+
     return 0;
 }
 
@@ -761,7 +772,11 @@ int SetPassword (
     if (as->parms[3].items) 
       sscanf (as->parms[3].items->data, "%d", &kvno);
 
+#ifdef AFS_S390_LINUX20_ENV
+    code = ubik_Call (KAM_SetPassword, conn, 0, name, instance, kvno, 0, key);
+#else
     code = ubik_Call (KAM_SetPassword, conn, 0, name, instance, kvno, key);
+#endif
     if (code) com_err (whoami, code,
 		       "so can't set password for %s.%s", name, instance);
     return code;
@@ -1313,7 +1328,7 @@ static int MyBeforeProc(
        if (code) {			/* if not then get key and try again */
 	  if (as->parms[13].items) { /* if password specified */
 	     strncpy (passwd, as->parms[13].items->data, sizeof(passwd));
-	     bzero (as->parms[13].items->data, strlen (as->parms[13].items->data));
+	     memset(as->parms[13].items->data, 0, strlen (as->parms[13].items->data));
 	  } else {
 	     char msg[MAXKTCNAMELEN+50];
 	     if (as->parms[12].items) sprintf (msg, "Administrator's (%s) Password: ", name);
@@ -1329,6 +1344,11 @@ static int MyBeforeProc(
 	  ka_StringToKey (passwd, cell, &key);
 	  code = ka_GetAdminToken (name, instance, cell, &key, KA_SIXHOURS,
 				   &token, 0/* !new */);
+	  if (code == KABADREQUEST) {
+	      des_string_to_key (passwd, &key);
+	      code = ka_GetAdminToken (name, instance, cell, &key, KA_SIXHOURS,
+				       &token, 0/* !new */);
+	  }
 	  if ((code == KABADREQUEST) && (strlen(passwd) > 8)) {
 	     /* try with only the first 8 characters incase they set
 	      * their password with an old style passwd program. */
@@ -1371,7 +1391,7 @@ static int MyBeforeProc(
 			"getting Authentication token for %s",
 			PrintedName (name, instance, cell));
 	  }
-	  bzero (&key, sizeof(key));
+	  memset(&key, 0, sizeof(key));
        }
     }
 
@@ -1429,9 +1449,10 @@ static ForgetTicket (
   char *arock)
 {
     afs_int32 code;
-    struct ktc_principal server;
 
 #ifdef notdef
+    struct ktc_principal server;
+
     if (as->parms[0].items) {
 	char *name = as->parms[0].items->data;
 	code = ka_ParseLoginName
