@@ -14,7 +14,7 @@
 #include <afs/param.h>
 #endif
 
-RCSID("$Header: /cvs/openafs/src/kauth/client.c,v 1.7.2.1 2001/09/19 22:40:34 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/client.c,v 1.7.2.2 2001/10/13 04:21:33 shadow Exp $");
 
 #if defined(UKERNEL)
 #include "../afs/sysincludes.h"
@@ -37,6 +37,13 @@ RCSID("$Header: /cvs/openafs/src/kauth/client.c,v 1.7.2.1 2001/09/19 22:40:34 sh
 #include <winsock2.h>
 #include <crypt.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include <afs/cellconfig.h>
 #include <afs/auth.h>
 #include <afs/afsutil.h>
