@@ -10,12 +10,11 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.9 2001/08/08 00:03:46 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.9.2.2 2001/10/13 04:21:33 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
-#include <fcntl.h>
 #include <winsock2.h>
 #include <WINNT/afsevent.h>
 #else
@@ -26,6 +25,16 @@ RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.9 2001/08/08 00:03:46 shad
 #include "kalog.h"           /* for OpenLog() */
 #include <time.h>
 #include <stdio.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
 #ifdef	AFS_AIX32_ENV
 #include <signal.h>
 #endif
@@ -55,7 +64,7 @@ int MinHours = 0;
 int npwSums = KA_NPWSUMS;               /* needs to be variable sometime */
 
 #include <stdarg.h>
-#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
+#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_XBSD_ENV)
 #undef vfprintf
 #define vfprintf(stream,fmt,args) _doprnt(fmt,args,stream)
 #endif
