@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/kauth/rebuild.c,v 1.7.2.1 2001/09/19 22:36:23 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/rebuild.c,v 1.7.2.2 2001/10/13 04:21:33 shadow Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -22,6 +22,13 @@ RCSID("$Header: /cvs/openafs/src/kauth/rebuild.c,v 1.7.2.1 2001/09/19 22:36:23 s
 #include <sys/file.h>
 #include <netinet/in.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif
+#endif
 #include <stdio.h>
 #include <errno.h>
 #include <time.h>
