@@ -7,6 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
+#include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/kauth/test/background.c,v 1.4 2001/07/12 19:58:40 shadow Exp $");
+
 main (argc, argv)
   int   argc;
   char *argv[];
