@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/kauth/user_nt.c,v 1.6.2.2 2001/11/21 06:45:49 shadow Exp $");
+
 #include <afs/stds.h>
 
 #include <windows.h>
@@ -45,6 +49,8 @@ static char *ka_MapKerberosError(int code)
 			return "server and client clocks are badly skewed";
 		case SKDC_RETRY:
 			return "Authentication Server was unavailable";
+		case RD_AP_TIME:
+			return "server and client clocks are badly skewed";
 		default:
 			sprintf(bogusReason, "unknown authentication error %d",
 				code);
@@ -79,6 +85,22 @@ afs_int32 ka_UserAuthenticateGeneral(
 	afs_int32 *password_expiresP,
 	afs_int32 spare,
 	char **reasonP)
+{
+  return ka_UserAuthenticateGeneral2(flags, name, instance, realm, password, NULL,
+				     lifetime, password_expiresP, spare, reasonP);
+}
+  
+afs_int32 ka_UserAuthenticateGeneral2(
+	afs_int32 flags,
+	char *name,
+	char *instance,
+	char *realm,
+	char *password,
+	char *smbname,
+	Date lifetime,
+	afs_int32 *password_expiresP,
+	afs_int32 spare,
+	char **reasonP)
 {
 	int code;
 	struct ktc_encryptionKey key1, key2;
@@ -90,6 +112,7 @@ afs_int32 ka_UserAuthenticateGeneral(
 	char fullRealm[256];
 	char upperRealm[256];
 	struct servent *sp;
+	int ttl;
 
 	struct ktc_principal server;
 	struct ktc_principal client;
@@ -100,6 +123,11 @@ afs_int32 ka_UserAuthenticateGeneral(
 
 	code = cm_SearchCellFile(realm, fullRealm, ka_AddHostProc, NULL);
 
+#ifdef AFS_AFSDB_ENV
+	if (code) {
+	  code = cm_SearchCellByDNS(realm, fullRealm, &ttl, ka_AddHostProc, NULL);
+        }
+#endif
 	if (code) {
 		*reasonP = "specified realm is unknown";
 		return (code);
@@ -135,6 +163,8 @@ afs_int32 ka_UserAuthenticateGeneral(
 	strcpy(client.name, name);
 	strcpy(client.instance, instance);
 	strcpy(client.cell, upperRealm);
+	if (smbname)
+	  strcpy(client.smbname, smbname);
 
 	token.startTime = 0;		/* XXX */
 	token.endTime = expirationTime;
@@ -304,24 +334,27 @@ static check_response
     ptr = (char *) cip->dat + 8;
 
     /* Check and extract server's name */
-    if ((strlen(ptr) + (ptr - (char *) cip->dat)) > cip->length)
-	return(INTK_BADPW);
+    if ((strlen(ptr) + (ptr - (char *) cip->dat)) > cip->length) {
+		return(INTK_BADPW);
+	}
 
     (void) strncpy(s_service, ptr, sizeof(s_service)-1);
     s_service[sizeof(s_service)-1] = '\0';
     ptr += strlen(s_service) + 1;
 
     /* Check and extract server's instance */
-    if ((strlen(ptr) + (ptr - (char *) cip->dat)) > cip->length)
-	return(INTK_BADPW);
+    if ((strlen(ptr) + (ptr - (char *) cip->dat)) > cip->length) {
+		return(INTK_BADPW);
+	}
 
     (void) strncpy(s_instance,ptr, sizeof(s_instance)-1);
     s_instance[sizeof(s_instance)-1] = '\0';
     ptr += strlen(s_instance) + 1;
 
     /* Check and extract server's realm */
-    if ((strlen(ptr) + (ptr - (char *) cip->dat)) > cip->length)
-	return(INTK_BADPW);
+    if ((strlen(ptr) + (ptr - (char *) cip->dat)) > cip->length) {
+		return(INTK_BADPW);
+	}
 
     (void) strncpy(s_realm,ptr, sizeof(s_realm));
     s_realm[sizeof(s_realm)-1] = '\0';
@@ -334,8 +367,9 @@ static check_response
     ticket_len = (unsigned char) *ptr++;
     
     if ((ticket_len < 0) ||
-	((ticket_len + (ptr - (char *) cip->dat)) > (int) cip->length))
+	((ticket_len + (ptr - (char *) cip->dat)) > (int) cip->length)) {
 	return(INTK_BADPW);
+	}
 
     /* Check returned server name, instance, and realm fields */
     /*
